from functools import wraps

from flask_restful import abort

from portal.service.errors import PortalAPIError


def error_handler(func):
    """Wraps the method and catches an PortalAPIException and calls abort
    Args:
        func: Wrapped method

    Returns: Wrapper function

    """
    @wraps(func)
    def _func(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except PortalAPIError as ex:
            abort(ex.code, **ex.message)

    return _func
